@@ -74,6 +74,8 @@ class ModelShell():
     <__main__.MyModel at 0x7f6bd9936c50>
     ```
     """
+    table_class_mapping = {}
+
     def __init__(self, model):
         """Store model primary key and class"""
         def get_id():
@@ -95,6 +97,10 @@ class ModelShell():
 
         self.id = get_id()
         self.model_class = model.__class__
+        # self.tablename = model.__tablename__
+        # if self.tablename not in self.table_class_mapping:
+        #     print('tablename not in mapping')
+        #     self.table_class_mapping[self.tablename] = model.__class__
         
     def unshell(self):
         """
@@ -107,9 +113,14 @@ class ModelShell():
             is returned. Otherwise, a `(model_class, id)` tuple is returned 
             which you can use to query the database to recover the model.
         """
+        # print('unshelling', self.model_class, self.id)
         if hasattr(self.model_class, 'query'):
             return self.model_class.query.get(self.id)
         return (self.model_class, self.id)
+        # model_class = self.table_class_mapping[self.tablename]
+        # if hasattr(model_class, 'query'):
+        #     return model_class.query.get(self.id)
+        # return (model_class, self.id)
     
     def __eq__(self, obj):
         return self.unshell() == obj
\ No newline at end of file
