@@ -70,6 +70,8 @@ class MutableDict(Mutable, dict):
             return obj
         if isinstance(obj, dict):
             return cls(obj)
+        if not obj:
+            return cls({})
         return super().coerce(cls, obj)
 
     # MutableDict has the following responsibilities:
@@ -141,7 +143,7 @@ class MutableDict(Mutable, dict):
             Shallow copy of `self` where all `ModelShell` values are unshelled.
         """
         return {
-            key: val.unshell() if isinstance(val, ModelShell) else val
+            key: val.unshell() if hasattr(val, 'unshell') else val
             for key, val in super().items()
         }
 
