@@ -63,7 +63,7 @@ class MutableList(Mutable, list):
     """
     @classmethod
     def coerce(cls, key, obj):
-        """Object must be list"""
+        """Object must be list or None"""
         if isinstance(obj, cls):
             return obj
         if isinstance(obj, list):
@@ -72,41 +72,18 @@ class MutableList(Mutable, list):
             return cls([])
         return cls([obj])
 
-    # MutableList has the following responsibilities:
-    # 1. Overload getstate and setstate for pickling
-    # 2. Register changes for list methods
-    # 3. Unshell models when returning list iterator
     def __init__(self, source=[], root=None):
         """
         _pickling indicates that the MutableList is being pickled. When 
         creating the list iterable during pickling, ModelShell objects 
         should not be unshelled.
         """
-        self._pickling = False
         super().__init__(self._convert_iterable(source))
     
     @property
     def _tracked_items(self):
         return list(self)
-
-    # 1. Pickling
     
-    # Note: _mapping is the index: value mapping of the list. It is used 
-    # only when pickling, and is therefore not a tracked attribute.
-    _untracked_attr_names = (
-        Mutable._untracked_attr_names + ['_mapping', '_pickling']
-    )
-
-    def __getstate__(self):
-        self._pickling = True
-        self._mapping = list(self)
-        return super().__getstate__()
-    
-    def __setstate__(self, state):
-        super().__setstate__(state)
-        self._pickling = False
-    
-    # 2. Register changes for list methods
     def __iadd__(self, items):
         self._changed()
         return super().__iadd__(self._convert_iterable(items))
@@ -156,7 +133,6 @@ class MutableList(Mutable, list):
         self._changed()
         return super().sort(key=key, reverse=reverse)
     
-    # 3. Unshell models when returning list iterator
     def unshell(self):
         """
         Call to force values to unshell. Normally this occurs automatically.
@@ -166,17 +142,7 @@ class MutableList(Mutable, list):
         copy : list
             Shallow copy of `self` where all `ModelShell` items are unshelled.
         """
-        return [i.unshell() if isinstance(i, ModelShell) else i for i in self]
-
-    def __iter__(self):
-        """
-        Note: ModelShells should not be unshelled when pickling.
-        """
-        for i in super().__iter__():
-            if not self._pickling and isinstance(i, ModelShell):
-                yield i.unshell()
-            else:
-                yield i
+        return [i.unshell() if hasattr(i, 'unshell') else i for i in self]
 
 
 MutableList.associate_with(MutableListType)
